==> haskell-persistent-sqlite-2.13.0.3-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-sqlite
version:              2.13.0.3
visibility:           public
id:                   persistent-sqlite-2.13.0.3-6mUF0melljOCnWk4UwSJAy
key:                  persistent-sqlite-2.13.0.3-6mUF0melljOCnWk4UwSJAy
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:             Database, Yesod
abi:                  0dd5bd764d7a91ab572d4d14ad7cbedb
exposed:              True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/persistent-sqlite-2.13.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/persistent-sqlite-2.13.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-sqlite
hs-libraries:         HSpersistent-sqlite-2.13.0.3-6mUF0melljOCnWk4UwSJAy
extra-libraries:      pthread sqlite3
depends:
    aeson-1.5.6.0-2S2293OVHlT9T87tqO4MGE base-4.15.1.0
    bytestring-0.10.12.1 conduit-1.3.4.2-3A7pGJm4Wj64vpyk0fAZNy
    containers-0.6.4.1 microlens-th-0.4.3.10-CAAiPodk0tn9fh7vbCRi5r
    monad-logger-0.3.36-FP2Q2gWeEc28MRX79ozn1C mtl-2.2.2
    persistent-2.13.3.1-Crfq0Q2hA8J5ipn4BkVv1a
    resource-pool-0.2.3.2-8nSWw6a4lYcZJpVlRxYsK
    resourcet-1.2.4.3-8QEUKrJZiOgDF8Ll7eoXIn text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 unliftio-core-0.2.0.1-HjGpVpPktr5Bc3kYrL6LtS
    unordered-containers-0.2.18.0-5p1LkGNUihlGGE57L3Yn33

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:         /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.13.0.3-151-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-sqlite
version:              2.13.0.3
visibility:           public
id:                   persistent-sqlite-2.13.0.3-88pdN6MYagQB51y9VCtcFS
key:                  persistent-sqlite-2.13.0.3-88pdN6MYagQB51y9VCtcFS
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:             Database, Yesod
abi:                  0774def6361d9250936af0b72fcd0352
exposed:              True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/persistent-sqlite-2.13.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/persistent-sqlite-2.13.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-sqlite
hs-libraries:         HSpersistent-sqlite-2.13.0.3-88pdN6MYagQB51y9VCtcFS
extra-libraries:      pthread sqlite3
depends:
    aeson-1.5.6.0-9Pr07X4KYAQGYkzJzuJMP6 base-4.15.1.0
    bytestring-0.10.12.1 conduit-1.3.4.2-ANsC6u5h1dvA454JbHPP8N
    containers-0.6.4.1 microlens-th-0.4.3.10-CAAiPodk0tn9fh7vbCRi5r
    monad-logger-0.3.36-FkYtHnTRuxF27nEZa96zZY mtl-2.2.2
    persistent-2.13.3.1-4NcpcutNa1D1rOVLkOUQ5
    resource-pool-0.2.3.2-4FjZ2sAAkLJBnOo3zq2XzI
    resourcet-1.2.5-8206UmUMunJDiN95rwKuqx text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 unliftio-core-0.2.0.1-HjGpVpPktr5Bc3kYrL6LtS
    unordered-containers-0.2.19.1-BhRjg5By7kU7pLGfSxEo3F

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:         /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
